@@ -8,16 +8,17 @@
 #define PDBDEBUGJOB_H
 
 #include <outputview/outputjob.h>
-#include <outputview/outputmodel.h>
-#include "debugsession.h"
+#include "startupinfo.h"
 
 namespace Python {
 
+class DebugSession;
+
 class DebugJob : public KDevelop::OutputJob
 {
 Q_OBJECT
 public:
-    DebugJob();
+    explicit DebugJob(const StartupInfo& info);
     ~DebugJob() override;
     
     /**
@@ -25,22 +26,10 @@ public:
      **/
     void start() override;
     bool doKill() override;
-    
-    QUrl m_scriptUrl;
-    QString m_interpreter;
-    QStringList m_args;
-    QUrl m_workingDirectory;
-    QString m_envProfileName;
-
-private Q_SLOTS:
-    void standardOutputReceived(QStringList lines);
-    void standardErrorReceived(QStringList lines);
 
 private:
-    OutputModel* outputModel();
+    const StartupInfo m_data;
     DebugSession* m_session;
-public Q_SLOTS:
-    void sessionFinished();
 };
 
 }
